@@ -1,6 +1,4 @@
 #!/usr/bin/env python
-#from __future__ import unicode_literals
-#from __future__ import print_function
 ###############################################################################
 # Name: Editra.py                                                             #
 # Purpose: Implements Editras App object and the Main method                  #
@@ -18,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 70495 2012-02-01 21:57:22Z CJP $"
-__revision__ = "$Revision: 70495 $"
+__svnid__ = "$Id: Editra.py 71188 2012-04-12 00:26:10Z CJP $"
+__revision__ = "$Revision: 71188 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -31,7 +29,7 @@ import sys
 # So ensure correct version of wxPython can be loaded
 if not hasattr(sys, 'frozen') and 'wx' not in sys.modules:
     import wxversion
-    wxversion.ensureMinimal(b'2.8')
+    wxversion.ensureMinimal('2.8')
 
 import codecs
 import base64
@@ -96,6 +94,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self._log = dev_tool.DEBUGP
         self._lock = False
         self._windows = dict()
+        self._isexiting = False
 
         # Disable debug popups
         wx.Log.EnableLogging(False)
@@ -215,12 +214,17 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
         # Setup Locale
         locale.setlocale(locale.LC_ALL, '')
-        self.locale = wx.Locale(ed_i18n.GetLangId(profiler.Profile_Get('LANG')))
-        if self.locale.GetCanonicalName() in ed_i18n.GetAvailLocales():
-            self.locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
-            self.locale.AddCatalog(ed_glob.PROG_NAME)
+        langId = ed_i18n.GetLangId(profiler.Profile_Get('LANG'))
+        if wx.Locale.IsAvailable(langId):
+            self.locale = wx.Locale()
+            if self.locale.GetCanonicalName() in ed_i18n.GetAvailLocales():
+                self.locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
+                self.locale.AddCatalog(ed_glob.PROG_NAME)
+            else:
+                del self.locale
+                self.locale = None
         else:
-            del self.locale
+            self._log("[app][err] The locale %s is not available!" %  profiler.Profile_Get('LANG'))
             self.locale = None
 
         # Check and set encoding if necessary
@@ -281,6 +285,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         @postcondition: Program may remain open if an open window is locking.
 
         """
+        self._isexiting = True
         self._pluginmgr.WritePluginConfig()
         profiler.TheProfile.Write(profiler.Profile_Get('MYPROFILE'))
         if not self._lock or force:
@@ -522,18 +527,21 @@ class Editra(wx.App, events.AppEventHandlerMixin):
             e_id = evt.GetId()
 
         if e_id == ed_glob.ID_EXIT:
+            self._isexiting = True
             # First loop is to ensure current top window is
             # closed first
             for win in self.GetMainWindows():
                 if win.IsActive():
                     result = win.Close()
                     if result:
+                        self._isexiting = False
                         break
                     return
             for win in self.GetMainWindows():
                 win.Raise()
                 result = win.Close()
                 if not result:
+                    self._isexiting = False
                     break
             self.Exit(force)
         else:
@@ -556,6 +564,11 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         @todo: move command processing into own module
 
         """
+        # Guard against events that come in after shutdown
+        # from server thread.
+        if not self or self._isexiting or not self.IsMainLoopRunning():
+            return
+
         self._log("[app][info] IN OnCommandReceived")
         cmds = evt.GetCommands()
         if isinstance(cmds, ed_ipc.IPCCommand):
@@ -1079,8 +1092,8 @@ def _Main(opts, args):
     # Print ipc server authentication info
     if '--auth' in opts:
         opts.pop('--auth')
-        print("port=%d,key=%s" % (ed_ipc.EDPORT,
-                                  profiler.Profile_Get('SESSION_KEY')))
+        print "port=%d,key=%s" % (ed_ipc.EDPORT,
+                                  profiler.Profile_Get('SESSION_KEY'))
 
     # Check if this is the only instance, if its not exit since
     # any of the opening commands have already been passed to the
