@@ -15,8 +15,8 @@ syntax highlighting of all supported filetypes.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_basestc.py 70747 2012-02-29 01:33:35Z CJP $"
-__revision__ = "$Revision: 70747 $"
+__svnid__ = "$Id: ed_basestc.py 71263 2012-04-23 00:42:30Z CJP $"
+__revision__ = "$Revision: 71263 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -1066,6 +1066,13 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                     self.SetProperty(prop[0], prop[1])
         return True
 
+    def BaseSetSelection(self, start, end):
+        """Call base STC SetSelection method, for use with internal utf-8
+        indexes in use by derived classes, STC hell...
+
+        """
+        super(EditraBaseStc, self).SetSelection(start, end)
+
     def SetSelection(self, start, end):
         """Override base method to make it work correctly using
         Unicode character positions instead of UTF-8.
@@ -1076,9 +1083,9 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         # Calculate UTF-8 offsets in buffer
         unicode_txt = self.GetText()
         if start != 0:
-            start = len(unicode_txt[0:start].encode('utf-8'))
+            start = len(ed_txt.EncodeString(unicode_txt[0:start], 'utf-8'))
         if end != 0:
-            end = len(unicode_txt[0:end].encode('utf-8'))
+            end = len(ed_txt.EncodeString(unicode_txt[0:end], 'utf-8'))
         super(EditraBaseStc, self).SetSelection(start, end)
 
     def GetSelection(self):
@@ -1088,9 +1095,9 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         start, end = super(EditraBaseStc, self).GetSelection()
         utf8_txt = self.GetTextUTF8()
         if start != 0:
-            start = len(utf8_txt[0:start].decode('utf-8'))
+            start = len(ed_txt.DecodeString(utf8_txt[0:start], 'utf-8'))
         if end != 0:
-            end = len(utf8_txt[0:end].decode('utf-8'))
+            end = len(ed_txt.DecodeString(utf8_txt[0:end], 'utf-8'))
         return start, end
 
     def ShowAutoCompOpt(self, command):
